@@ -126,14 +126,20 @@ class MyWhatify:
                 my_toolkit.Ensemble.remove_ensemble_in_production(ensemble_id=ensemble_id)
 
     @classmethod
-    def run_prediction(cls, data_name, ensemble_id, data_file=None, wait=True, file_path=None, header=None, data_id=None):
+    def run_prediction(cls, data_name, ensemble_id, data_file=None, wait=True, file_path=None, header=None,
+                       data_id=None, skip_if_exist=False):
         with allure.step('running prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) + ' and wait is: ' + str(wait)):
-            print('running prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) + ' and wait is: ' + str(wait))
-            logging.info('running prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) + ' and wait is: ' + str(wait))
+            print('running prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) +
+                  ' and wait is: ' + str(wait) + ' with skip_if_exist: ' + str(skip_if_exist))
+            logging.info('running prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) + ' and wait is: ' + str(wait) )
             status = True
             predict_id = None
             message = None
             # data_file.drop(data_file.columns[len(df.columns) - 1], axis=1, inplace=True)
+            if skip_if_exist:
+                ret_list = cls.get_prediction_list(prediction_name=data_name)
+                if len(ret_list) > 0:
+                    return int(ret_list[0]['id']), True, None
             try:
                 if not (file_path or data_id):
                     data_id = my_toolkit.Datasource.create_from_dataframe(df=data_file, data_source_name=data_name,
